import { __decorate, __param } from "tslib";
import { DI } from '@microsoft/fast-foundation';
import { LoginMapper } from './loginMapper';
import { LogoutMapper } from './logoutMapper';
import { DefaultMessageMapper } from './map';
import { MESSAGE_TYPE } from '../dto';
/**
 * Default AuthMessageMapper.
 * @public
 */
let DefaultAuthMessageMapper = class DefaultAuthMessageMapper extends DefaultMessageMapper {
    constructor(loginMapper, logoutMapper) {
        super();
        this.loginMapper = loginMapper;
        this.logoutMapper = logoutMapper;
        this.set(MESSAGE_TYPE.LOGIN_ACK, loginMapper);
        this.set(MESSAGE_TYPE.LOGIN_NACK, loginMapper);
        this.set(MESSAGE_TYPE.LOGIN_DETAILS_ACK, loginMapper);
        this.set(MESSAGE_TYPE.LOGIN_DETAILS_NACK, loginMapper);
        this.set(MESSAGE_TYPE.LOGOUT_ACK, logoutMapper);
        this.set(MESSAGE_TYPE.LOGOUT_NACK, logoutMapper);
    }
};
DefaultAuthMessageMapper = __decorate([
    __param(0, LoginMapper),
    __param(1, LogoutMapper)
], DefaultAuthMessageMapper);
export { DefaultAuthMessageMapper };
/**
 * AuthMessageMapper DI key.
 *
 * @privateRemarks
 * Marked as internal to stop api-extractor becoming confused cross-linking tokens with the same name.
 *
 * @internal
 */
export const AuthMessageMapper = DI.createInterface((x) => x.singleton(DefaultAuthMessageMapper));
// type z = keyof AuthMessageMapperLookup;
// const x = new DefaultAuthMessageMapper();
// const mapper = x.get(MESSAGE_TYPE.LOGIN_DETAILS_ACK);
